@@ -117,6 +117,7 @@ def get_symbol(query):
     try:
         data = yq.search(query)
     except ValueError: 
+        print(query)
     else:
         quotes = data['quotes'] 
         if len(quotes) == 0:
@@ -280,7 +281,6 @@ def get_closing_price_viz(company_list, comp_names):
     plt.subplots_adjust(top=1.25, bottom=1.2)
 
     for i, company in enumerate(company_list, 1): 
-        print('company', company)
         plt.subplot(2, 2, i)
         company['Adj Close'].plot()
         plt.ylabel('Adj Close')
@@ -370,7 +370,7 @@ def create_pricelist(close_prices, windown_size = 30):
     return result_list
 
 
-def predict_future_price(data_list = None, windown_size=30, predict_window_size=10, predict=False):
+def predict_future_price(data_list, comp_names_abbr, windown_size=30, predict_window_size=10, predict=True):
     """
     Predict future price. 
 
